@@ -3,10 +3,10 @@
 # Copyright © 2013 Spyder Project Contributors
 # Licensed under the terms of the MIT License
 # (see LICENSE.txt for details)
-"""Spyder unitest plugin."""
+"""Spyder unittest plugin."""
 
 # Local imports
 from .unittestplugin import UnitTestPlugin as PLUGIN_CLASS
 
-__version__ = '0.5.1'
+__version__ = '0.6.0'
 PLUGIN_CLASS
