@@ -14,7 +14,9 @@ from qtpy import PYQT4
 from qtpy.QtCore import QAbstractItemModel, QModelIndex, Qt, Signal
 from qtpy.QtGui import QBrush, QColor, QFont
 from qtpy.QtWidgets import QMenu, QTreeView
+from spyder.api.config.mixins import SpyderConfigurationAccessor
 from spyder.config.base import get_translation
+from spyder.utils.palette import QStylePalette, SpyderPalette
 from spyder.utils.qthelpers import create_action
 
 # Local imports
@@ -28,19 +30,11 @@ except KeyError:
     _ = gettext.gettext
 
 COLORS = {
-    Category.OK: QBrush(QColor("#C1FFBA")),
-    Category.FAIL: QBrush(QColor("#FF5050")),
-    Category.SKIP: QBrush(QColor("#C5C5C5")),
-    Category.PENDING: QBrush(QColor("#C5C5C5")),
-    Category.COVERAGE: QBrush(QColor("#89CFF0"))
-}
-
-COLORS_DARK = {
-    Category.OK: QBrush(QColor("#008000")),
-    Category.FAIL: QBrush(QColor("#C6001E")),
-    Category.SKIP: QBrush(QColor("#505050")),
-    Category.PENDING: QBrush(QColor("#505050")),
-    Category.COVERAGE: QBrush(QColor("#0047AB"))
+    Category.OK:       SpyderPalette.COLOR_SUCCESS_1,
+    Category.FAIL:     SpyderPalette.COLOR_ERROR_1,
+    Category.SKIP:     SpyderPalette.COLOR_WARN_1,
+    Category.PENDING:  QStylePalette.COLOR_BACKGROUND_1,
+    Category.COVERAGE: QStylePalette.COLOR_ACCENT_1
 }
 
 STATUS_COLUMN = 0
@@ -61,9 +55,13 @@ class TestDataView(QTreeView):
     -------
     sig_edit_goto(str, int): Emitted if editor should go to some position.
         Arguments are file name and line number (zero-based).
+    sig_single_test_run_requested(str): Emitted to request a single test
+        to be run. Argument is the name of the test.
     """
 
     sig_edit_goto = Signal(str, int)
+    sig_single_test_run_requested = Signal(str)
+
     __test__ = False  # this is not a pytest test class
 
     def __init__(self, parent=None):
@@ -126,6 +124,13 @@ class TestDataView(QTreeView):
                 lineno = 0
             self.sig_edit_goto.emit(filename, lineno)
 
+    def run_single_test(self, index):
+        """Ask plugin to run only the test corresponding to index."""
+        index = self.make_index_canonical(index)
+        testresult = self.model().testresults[index.row()]
+        testname = testresult.name
+        self.sig_single_test_run_requested.emit(testname)
+
     def make_index_canonical(self, index):
         """
         Convert given index to canonical index for the same test.
@@ -152,12 +157,21 @@ class TestDataView(QTreeView):
                                      triggered=lambda: self.expand(index))
             menuItem.setEnabled(self.model().hasChildren(index))
         contextMenu.addAction(menuItem)
+
         menuItem = create_action(
                 self, _('Go to definition'),
                 triggered=lambda: self.go_to_test_definition(index))
         test_location = self.model().data(index, Qt.UserRole)
         menuItem.setEnabled(test_location[0] is not None)
         contextMenu.addAction(menuItem)
+
+        menuItem = create_action(
+                self, _('Run only this test'),
+                triggered=lambda: self.run_single_test(index))
+        result_category = self.model().testresults[index.row()].category
+        menuItem.setEnabled(result_category != Category.COVERAGE)
+        contextMenu.addAction(menuItem)
+
         return contextMenu
 
     def resizeColumns(self):
@@ -186,7 +200,7 @@ class TestDataView(QTreeView):
                 self.setFirstColumnSpanned(i, index, True)
 
 
-class TestDataModel(QAbstractItemModel):
+class TestDataModel(QAbstractItemModel, SpyderConfigurationAccessor):
     """
     Model class storing test results for display.
 
@@ -198,17 +212,14 @@ class TestDataModel(QAbstractItemModel):
     a tuple (row, column, id). The id is TOPLEVEL_ID for top-level items.
     For level-2 items, the id is the index of the test in `self.testresults`.
 
-    Attributes
-    ----------
-    is_dark_interface : bool
-        Whether to use colours appropriate for a dark user interface.
-
     Signals
     -------
     sig_summary(str)
        Emitted with new summary if test results change.
     """
 
+    CONF_SECTION = 'unittest'
+
     sig_summary = Signal(str)
     __test__ = False  # this is not a pytest test class
 
@@ -216,7 +227,6 @@ class TestDataModel(QAbstractItemModel):
         """Constructor."""
         QAbstractItemModel.__init__(self, parent)
         self.abbreviator = Abbreviator()
-        self.is_dark_interface = False
         self.testresults = []
         try:
             self.monospace_font = parent.window().editor.get_plugin_font()
@@ -321,10 +331,14 @@ class TestDataModel(QAbstractItemModel):
             elif column == STATUS_COLUMN:
                 return self.testresults[row].status
             elif column == NAME_COLUMN:
+                name = self.testresults[row].name
                 # don't abbreviate for the code coverage filename
                 if self.testresults[row].category == Category.COVERAGE:
-                    return self.testresults[row].name
-                return self.abbreviator.abbreviate(self.testresults[row].name)
+                    return name
+                if self.get_conf('abbrev_test_names', False):
+                    return self.abbreviator.abbreviate(name)
+                else:
+                    return name
             elif column == MESSAGE_COLUMN:
                 return self.testresults[row].message
             elif column == TIME_COLUMN:
@@ -339,10 +353,8 @@ class TestDataModel(QAbstractItemModel):
         elif role == Qt.BackgroundRole:
             if id == TOPLEVEL_ID:
                 testresult = self.testresults[row]
-                if self.is_dark_interface:
-                    return COLORS_DARK[testresult.category]
-                else:
-                    return COLORS[testresult.category]
+                color = COLORS[testresult.category]
+                return QBrush(QColor(color))
         elif role == Qt.TextAlignmentRole:
             if id == TOPLEVEL_ID and column == TIME_COLUMN:
                 return Qt.AlignRight
